# coding: utf-8

module Morchi
  
  # The board class.
  class Board

    # Property
    attr_reader :size

    # Initialize.
    def initialize(num)
      @size = num
      @range = 0..(@size - 1)
      clear
    end

    # Get disk
    def [](row, col)
      return false unless include?(row, col)
      @board[index(row, col)]
    end

    # Set disk
    def []=(row, col, value)
      fail OutOfRangeError.new unless include?(row, col)
      @board[index(row, col)] = value
    end

    # Clear.
    def clear
      @board = Array.new(@size ** 2, Morchi::Disk.empty)
    end

    # Query, is full?
    def full?
      (@size ** 2).times do |index|
        return false if @board[index].empty?
      end
      true
    end

  private

    # Is include?
    def include?(row, col)
      @range.include?(row) && @range.include?(col)
    end

    # Get index.
    def index(row, col)
      (row * @size) + col
    end
  end
end
